@@ -42,8 +42,10 @@ tssem1FEM <- function(my.df, n, cor.analysis=TRUE, model.name=NULL,
 
     ## Prepare starting values based on covariance matrices
     sv <- .startValues(my.df, cor.analysis = FALSE)
-    # matrix of labels; only use the lower triangle
-    ps.labels <- outer(1:no.var, 1:no.var, function(x, y) paste("s", x, y, sep = ""))
+      
+    ## matrix of labels; only use the lower triangle
+    ## Fixed a bug reported by John Ma when there are more than 120 variables by replacing " " with "_"  
+    ps.labels <- outer(1:no.var, 1:no.var, function(x, y) paste0("s", x, "_", y))
     if (cor.analysis==TRUE) {
       S <- mxMatrix(type="Stand", nrow=no.var, ncol=no.var, free=TRUE, values=vechs(cov2cor(sv)),
                     labels=vechs(ps.labels), name="S")
